@@ -277,7 +277,7 @@ class WhooshSearchBackend(BaseSearchBackend):
     def calculate_page(self, start_offset=0, end_offset=None):
         # Prevent against Whoosh throwing an error. Requires an end_offset
         # greater than 0.
-        if not end_offset is None and end_offset <= 0:
+        if end_offset is not None and end_offset <= 0:
             end_offset = 1
 
         # Determine the page.
@@ -353,7 +353,7 @@ class WhooshSearchBackend(BaseSearchBackend):
                     if len(sort_by_list) == 1:
                         reverse = False
 
-            sort_by = sort_by_list[0]
+            sort_by = sort_by_list
 
         if facets is not None:
             warnings.warn("Whoosh does not handle faceting.", Warning, stacklevel=2)
@@ -404,7 +404,7 @@ class WhooshSearchBackend(BaseSearchBackend):
                 if narrowed_results:
                     narrowed_results.filter(recent_narrowed_results)
                 else:
-                   narrowed_results = recent_narrowed_results
+                    narrowed_results = recent_narrowed_results
 
         self.index = self.index.refresh()
 
@@ -484,10 +484,6 @@ class WhooshSearchBackend(BaseSearchBackend):
         if not self.setup_complete:
             self.setup()
 
-        # Deferred models will have a different class ("RealClass_Deferred_fieldname")
-        # which won't be in our registry:
-        model_klass = model_instance._meta.concrete_model
-
         field_name = self.content_field_name
         narrow_queries = set()
         narrowed_results = None
@@ -533,13 +529,14 @@ class WhooshSearchBackend(BaseSearchBackend):
                 if narrowed_results:
                     narrowed_results.filter(recent_narrowed_results)
                 else:
-                   narrowed_results = recent_narrowed_results
+                    narrowed_results = recent_narrowed_results
 
         page_num, page_length = self.calculate_page(start_offset, end_offset)
 
         self.index = self.index.refresh()
         raw_results = EmptyResults()
 
+        searcher = None
         if self.index.doc_count():
             query = "%s:%s" % (ID, get_identifier(model_instance))
             searcher = self.index.searcher()
@@ -575,7 +572,9 @@ class WhooshSearchBackend(BaseSearchBackend):
             }
 
         results = self._process_results(raw_page, result_class=result_class)
-        searcher.close()
+
+        if searcher:
+            searcher.close()
 
         if hasattr(narrow_searcher, 'close'):
             narrow_searcher.close()
@@ -900,13 +899,6 @@ class WhooshSearchQuery(BaseSearchQuery):
         return u"%s%s" % (index_fieldname, query_frag)
 
 
-        # if not filter_type in ('in', 'range'):
-        #     # 'in' is a bit of a special case, as we don't want to
-        #     # convert a valid list/tuple to string. Defer handling it
-        #     # until later...
-        #     value = self.backend._from_python(value)
-
-
 class WhooshEngine(BaseEngine):
     backend = WhooshSearchBackend
     query = WhooshSearchQuery
