@@ -147,12 +147,12 @@ class SearchQuerySet(object):
                 current_position += 1
 
             if self._cache_is_full():
-                raise StopIteration
+                return
 
             # We've run out of results and haven't hit our limit.
             # Fill more of the cache.
             if not self._fill_cache(current_position, current_position + ITERATOR_LOAD_PER_QUERY):
-                raise StopIteration
+                return
 
     def post_process_results(self, results):
         to_cache = []
@@ -172,23 +172,32 @@ class SearchQuerySet(object):
 
         for result in results:
             if self._load_all:
-                # We have to deal with integer keys being cast from strings
-                model_objects = loaded_objects.get(result.model, {})
-                if result.pk not in model_objects:
-                    try:
-                        result.pk = int(result.pk)
-                    except ValueError:
-                        pass
-                try:
-                    result._object = model_objects[result.pk]
-                except KeyError:
-                    # The object was either deleted since we indexed or should
-                    # be ignored; fail silently.
-                    self._ignored_result_count += 1
 
-                    # avoid an unfilled None at the end of the result cache
-                    self._result_cache.pop()
-                    continue
+                model_objects = loaded_objects.get(result.model, {})
+                # Try to coerce a primary key object that matches the models pk
+                # We have to deal with semi-arbitrary keys being cast from strings (UUID, int, etc)
+                if model_objects:
+                    result_klass = type(next(iter(model_objects)))
+                    result.pk = result_klass(result.pk)
+
+                    try:
+                        result._object = model_objects[result.pk]
+                    except KeyError:
+                        # The object was either deleted since we indexed or should
+                        # be ignored for other reasons such as an overriden 'load_all_queryset';
+                        # fail silently.
+                        self._ignored_result_count += 1
+
+                        # avoid an unfilled None at the end of the result cache
+                        self._result_cache.pop()
+                        continue
+                else:
+                    # No objects were returned -- possible due to SQS nesting such as
+                    # XYZ.objects.filter(id__gt=10) where the amount ignored are
+                    # exactly equal to the ITERATOR_LOAD_PER_QUERY
+                    del self._result_cache[:len(results)]
+                    self._ignored_result_count += len(results)
+                    break
 
             to_cache.append(result)
 
