@@ -11,7 +11,8 @@ from django.utils import six
 from haystack.constants import ID, DJANGO_CT, DJANGO_ID
 from haystack.utils.highlighting import Highlighter
 
-IDENTIFIER_REGEX = re.compile('^[\w\d_]+\.[\w\d_]+\.\d+$')
+
+IDENTIFIER_REGEX = re.compile('^[\w\d_]+\.[\w\d_]+\.[\w\d-]+$')
 
 
 def default_get_identifier(obj_or_string):
@@ -69,6 +70,7 @@ def get_model_ct_tuple(model):
         if hasattr(model, '_deferred') and model._deferred else model._meta.model_name
     return (model._meta.app_label, model_name)
 
+
 def get_model_ct(model):
     return "%s.%s" % get_model_ct_tuple(model)
 
