@@ -51,18 +51,18 @@ TEMPLATES = [
     },
 ]
 
-MIDDLEWARE_CLASSES = [
+MIDDLEWARE = [
     'django.middleware.common.CommonMiddleware',
     'django.contrib.sessions.middleware.SessionMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
     'django.contrib.auth.middleware.AuthenticationMiddleware',
-    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
     'django.contrib.messages.middleware.MessageMiddleware',
 ]
 
 ROOT_URLCONF = 'test_haystack.core.urls'
 
-HAYSTACK_ROUTERS = ['haystack.routers.DefaultRouter', 'test_haystack.multipleindex.routers.MultipleIndexRouter']
+HAYSTACK_ROUTERS = ['haystack.routers.DefaultRouter',
+    'test_haystack.multipleindex.routers.MultipleIndexRouter']
 
 HAYSTACK_CONNECTIONS = {
     'default': {
@@ -89,17 +89,19 @@ HAYSTACK_CONNECTIONS = {
     },
     'solr': {
         'ENGINE': 'haystack.backends.solr_backend.SolrEngine',
-        'URL': os.environ.get('TEST_SOLR_URL', 'http://localhost:9001/solr/'),
+        'URL': os.environ.get('TEST_SOLR_URL', 'http://localhost:9001/solr/collection1'),
+        'ADMIN_URL': os.environ.get('TEST_SOLR_ADMIN_URL', 'http://localhost:9001/solr/admin/cores'),
         'INCLUDE_SPELLING': True,
     },
 }
 
-try:
-    import elasticsearch
+if 'elasticsearch' in HAYSTACK_CONNECTIONS:
+    try:
+        import elasticsearch
 
-    if (2, ) <= elasticsearch.__version__ <= (3, ):
-        HAYSTACK_CONNECTIONS['elasticsearch'].update({
-            'ENGINE': 'haystack.backends.elasticsearch2_backend.Elasticsearch2SearchEngine'
-        })
-except ImportError:
-    del HAYSTACK_CONNECTIONS['elasticsearch']
+        if (2, ) <= elasticsearch.__version__ <= (3, ):
+            HAYSTACK_CONNECTIONS['elasticsearch'].update({
+                'ENGINE': 'haystack.backends.elasticsearch2_backend.Elasticsearch2SearchEngine'
+            })
+    except ImportError:
+        del HAYSTACK_CONNECTIONS['elasticsearch']
